@@ -4,7 +4,8 @@ use 5.14.0;
 
 package Dist::Zilla::Plugin::PkgVersion::Block {
 
-    our $VERSION = '0.0107'; # VERSION
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.0200';
 
     use Moose;
     with('Dist::Zilla::Role::FileMunger',
@@ -111,22 +112,21 @@ Dist::Zilla::Plugin::PkgVersion::Block - PkgVersion for block packages
 
 
 
-=begin HTML
+=begin html
 
-<p><img src="https://img.shields.io/badge/perl-5.14+-brightgreen.svg" alt="Requires Perl 5.14+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Zilla-Plugin-PkgVersion-Block"><img src="https://api.travis-ci.org/Csson/p5-Dist-Zilla-Plugin-PkgVersion-Block.svg?branch=master" alt="Travis status" /></a></p>
+<p>
+<img src="https://img.shields.io/badge/perl-5.14+-blue.svg" alt="Requires Perl 5.14+" />
+<a href="https://travis-ci.org/Csson/p5-Dist-Zilla-Plugin-PkgVersion-Block"><img src="https://api.travis-ci.org/Csson/p5-Dist-Zilla-Plugin-PkgVersion-Block.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/release/CSSON/Dist-Zilla-Plugin-PkgVersion-Block-0.0200"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Dist-Zilla-Plugin-PkgVersion-Block/0.0200" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Dist-Zilla-Plugin-PkgVersion-Block%200.0200"><img src="http://badgedepot.code301.com/badge/cpantesters/Dist-Zilla-Plugin-PkgVersion-Block/0.0200" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-80.0%-orange.svg" alt="coverage 80.0%" />
+</p>
 
-=end HTML
-
-
-=begin markdown
-
-![Requires Perl 5.14+](https://img.shields.io/badge/perl-5.14+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Zilla-Plugin-PkgVersion-Block.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Zilla-Plugin-PkgVersion-Block)
-
-=end markdown
+=end html
 
 =head1 VERSION
 
-Version 0.0107, released 2015-05-31.
+Version 0.0200, released 2018-08-26.
 
 =head1 SYNOPSIS
 
@@ -205,7 +205,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
